        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 23 <strong>control</strong><br>0,4,5,7,9,12,13,14,17,19,24,26,27,28,29,30,31,32,35,36,40,44,47';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>33</strong> miembros: 18 <br>3,8,10,15,20,21,22,25,33,34,38,39,41,42,43,48,49,50';}
       if(rr==6 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 10 <br>1,2,6,11,16,18,23,37,45,46';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 23 <strong>control</strong><br>0,4,5,7,9,12,13,14,17,19,24,26,27,28,29,30,31,32,35,36,40,44,47';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>33</strong> miembros: 18 <br>3,8,10,15,20,21,22,25,33,34,38,39,41,42,43,48,49,50';}
       if(rr==29 && cc==3){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 10 <br>1,2,6,11,16,18,23,37,45,46';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 23 <strong>control</strong><br>0,4,5,7,9,12,13,14,17,19,24,26,27,28,29,30,31,32,35,36,40,44,47';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>33</strong> miembros: 18 <br>3,8,10,15,20,21,22,25,33,34,38,39,41,42,43,48,49,50';}
       if(rr==30 && cc==3){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 10 <br>1,2,6,11,16,18,23,37,45,46';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 23 <strong>control</strong><br>0,4,5,7,9,12,13,14,17,19,24,26,27,28,29,30,31,32,35,36,40,44,47';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>33</strong> miembros: 18 <br>3,8,10,15,20,21,22,25,33,34,38,39,41,42,43,48,49,50';}
       if(rr==31 && cc==3){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 10 <br>1,2,6,11,16,18,23,37,45,46';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 23 <strong>control</strong><br>0,4,5,7,9,12,13,14,17,19,24,26,27,28,29,30,31,32,35,36,40,44,47';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>33</strong> miembros: 18 <br>3,8,10,15,20,21,22,25,33,34,38,39,41,42,43,48,49,50';}
       if(rr==32 && cc==3){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 10 <br>1,2,6,11,16,18,23,37,45,46';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 23 <strong>control</strong><br>0,4,5,7,9,12,13,14,17,19,24,26,27,28,29,30,31,32,35,36,40,44,47';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>33</strong> miembros: 18 <br>3,8,10,15,20,21,22,25,33,34,38,39,41,42,43,48,49,50';}
       if(rr==33 && cc==3){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 10 <br>1,2,6,11,16,18,23,37,45,46';}
}
